@@ -73,7 +73,7 @@ eel_alert_dialog_get_type (void)
 
 	if (!dialog_type) {
 	
-		static const GTypeInfo dialog_info =
+		const GTypeInfo dialog_info =
 		{
 			sizeof (EelAlertDialogClass),
 			NULL,
